# Projeto - Pacote de Processamento de Imagens

Autora do Projeto - Karina Kato

Bootcamp Cognizant Cloud Data Engineer - DIO


Descrição
O pacote "image-processing-test-project" é usado para:

Módulo "Processamento":

Correspondência de histograma;
Similaridade estrutural;
Redimensionar imagem;

Módulo "Utils":

Ler imagem;
Salvar imagem;
Plotar imagem;
Resultado do gráfico;
Plotar histograma;


```bash
pip install image-processing-test-project
```

## Usage

```python
from package_name.module1_name import file1_name
file1_name.my_function()
```

# Author (Quem hospedou o projeto no Test Py)
Fernando Ventura


## License
[MIT](https://choosealicense.com/licenses/mit/)